@@ -1,6 +1,7 @@
-/* graphics.h - graphics code for SciteProj
+/**
+ * graphics.h - graphics code for SciteProj
  *
- *  Copyright 2009-2011 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -27,6 +28,9 @@
 extern GdkPixbuf *header_file_pixbuf;
 extern GdkPixbuf *cpp_file_pixbuf;
 extern GdkPixbuf *txt_file_pixbuf;
+extern GdkPixbuf *lua_file_pixbuf;
+extern GdkPixbuf *java_file_pixbuf;
+
 extern GdkPixbuf *directory_closed_pixbuf;
 extern GdkPixbuf *directory_open_pixbuf;
 
