@@ -1,6 +1,7 @@
-/* gui.c - GUI code for SciteProj
+/**
+ * gui.c - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -28,6 +29,8 @@
 
 #include <stdlib.h>
 
+#include "clicked_node.h"
+
 #include "gui.h"
 #include "drag_drop.h"
 #include "tree_manipulation.h"
@@ -41,51 +44,55 @@
 #include "file_utils.h"
 
 #include "search.h"
-#include "rename.h"
 #include "clipboard.h"
 
+#include "rename.h"
+#include "remove.h"
+#include "addfiles.h"
+
+#include "recent_files.h"
+#include "filelist.h"
+
 #include "menus.h"
 
+#include "search.h"
+
 
 #define APP_SCITEPROJ_ERROR g_quark_from_static_string("APP_GUI_ERROR")
 
 
 // Forward-declare static functions
 
-gboolean dialog_response_is_exit(gint test);
+//gboolean dialog_response_is_exit(gint test);
 
 static gint window_delete_event_cb(GtkWidget *widget, GdkEvent *event, gpointer data);
 static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkTreeViewColumn *column, gpointer userData);
 static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *event, gpointer userData);
 
-static void ask_name_add_group(GtkTreeIter *nodeIter);
+//static void ask_name_add_group(GtkTreeIter *nodeIter);
 
 static void row_expand_or_collapse_cb(GtkTreeView *treeview, GtkTreeIter *arg1, GtkTreePath *arg2, gpointer user_data);
 
-static void menu_add_widget_cb(GtkUIManager *ui, GtkWidget *widget, GtkContainer *container);
+//static void menu_add_widget_cb(GtkUIManager *ui, GtkWidget *widget, GtkContainer *container);
 
 static void quit_menu_cb();
 static void about_menu_cb();
-static void usage_menu_cb();
 static void saveproject_menu_cb();
 static void saveproject_as_menu_cb();
 static void openproject_menu_cb();
-static void addfile_menu_cb();
+//static void addfile_menu_cb();
 static void creategroup_menu_cb();
 
-static void popup_add_files_cb();
 static void popup_open_file_cb();
-static void popup_add_group_cb();
-static void popup_remove_node_cb();
 
 static void expand_all_items_cb();
 static void collapse_all_items_cb();
 
-static void removeitem_menu_cb();
-
 static void sort_ascending_cb();
 static void sort_descending_cb();
 
+void recent_files_switch_visible();
+
 gboolean tree_view_search_equal_func(GtkTreeModel *model,gint column,const gchar *key,GtkTreeIter *iter,gpointer search_data);
 
 static void edit_options_cb();
@@ -101,6 +108,7 @@ static GtkActionEntry sMenuActions[] =
 {
 	{ "FileMenuAction", NULL, "_File" },
 	{ "EditMenuAction", NULL, "_Edit" },
+	{ "ViewMenuAction", NULL, "_View" },
 	{ "HelpMenuAction", NULL, "_Help" },
 	
 	{ "OpenProjectAction", GTK_STOCK_OPEN, "_Open Project", "<control>O", "Open Project", G_CALLBACK(openproject_menu_cb) },
@@ -115,7 +123,8 @@ static GtkActionEntry sMenuActions[] =
 	{ "ExpandAllGroupsAction", NULL, "Expand All Groups", "<control><shift>E", "Expand All Groups", G_CALLBACK(expand_all_items_cb) },
 	{ "CollapseAllGroupsAction", NULL, "Collapse All Groups", "<control><shift>C", "Collapse All Groups", G_CALLBACK(collapse_all_items_cb) },
 	
-	{ "UsageAction", GTK_STOCK_HELP, "_Usage", "", "Show command line usage", G_CALLBACK(usage_menu_cb) },
+	{ "SearchAction", GTK_STOCK_FIND, "Search", "<control>F", "Search for a string in the project", G_CALLBACK(search_dialog_cb) },
+	
 	{ "AboutAction", GTK_STOCK_ABOUT, "_About", "", "Show information about this application", G_CALLBACK(about_menu_cb) },
 	
 	{ "AddFilesPopupAction", GTK_STOCK_FILE, "Add Files", "", "Add files to the project", G_CALLBACK(popup_add_files_cb) },
@@ -130,21 +139,27 @@ static GtkActionEntry sMenuActions[] =
 	{ "PropertiesGroupPopupAction", GTK_STOCK_PROPERTIES, "Group Properties", "", "Show group properties", G_CALLBACK(group_properties_cb) },
 	{ "EditOptionsAction", GTK_STOCK_PROPERTIES, "Edit Options", "", "Edit Program Options", G_CALLBACK(edit_options_cb) },
 	
+	{ "ViewRecentAction" , GTK_STOCK_PROPERTIES, "View Recently Opened Files", "<control>R", "View Recent Files", G_CALLBACK(recent_files_switch_visible) },
+	
 	{ "OpenFilePopupAction", GTK_STOCK_OPEN, "Open File in SciTE", "", "Open a file in SciTE", G_CALLBACK(popup_open_file_cb) },
 	{ "RemoveFilePopupAction", GTK_STOCK_DELETE, "Remove File From Project", "", "Remove a file from the project", G_CALLBACK(popup_remove_node_cb) },
 	{ "CopyFilenameToClipBoardAction", GTK_STOCK_COPY, "Copy Filename to Clipboard", "", "Copies the full path and filename to the clipboard", G_CALLBACK(copy_filename_to_clipboard_cb) },
-	{ "PropertiesPopupAction", GTK_STOCK_PROPERTIES, "File Properties", "", "Show file properties", G_CALLBACK(file_properties_cb) }
+	{ "PropertiesPopupAction", GTK_STOCK_PROPERTIES, "File Properties", "", "Show file properties", G_CALLBACK(file_properties_cb) },
+	
+	{ "OpenRecentFilePopupAction", GTK_STOCK_OPEN, "Open File in SciTE", "", "Open a file in SciTE", G_CALLBACK(popup_open_recent_file_cb) },
+	{ "RemoveRecentFilePopupAction", GTK_STOCK_DELETE, "Remove File from this List", "", "Remove file from this List", G_CALLBACK(popup_remove_recent_file_cb) },
+	{ "CopyRecentToClipboardAction", GTK_STOCK_COPY, "Copy filename to clipboard", "", "Copy filename to clipboard", G_CALLBACK(copy_recent_filename_to_clipboard_cb) },
+	
+	{ "PropertiesRecentPopupAction", GTK_STOCK_PROPERTIES, "File Properties", "", "Show file properties", G_CALLBACK(properties_recent_file_cb) }
 
 };
 
 static guint sNumMenuActions = G_N_ELEMENTS(sMenuActions);
 
-
-
 static TreeViewDragStruct sDragStruct;
 
 static GtkWidget *sMainWindow = NULL;
-GtkWidget *sTreeView = NULL;
+GtkWidget *projectTreeView = NULL;
 
 static GtkWidget *sGroupPopupMenu = NULL;
 static GtkWidget *sFilePopupMenu = NULL;
@@ -160,6 +175,11 @@ GtkCellRenderer *pixbuffCellRenderer = NULL;
 
 GtkWidget *scrolledWindow = NULL;
 
+GtkTreeViewColumn *column1 = NULL;
+
+GtkWidget *recentVbox=NULL;
+
+
 /**
  * Initialize globals (i.e. create the main window and populate it).  This is a long chunk of code.
  *
@@ -172,14 +192,23 @@ gboolean setup_gui(GError **err)
 	gboolean resultCode = FALSE;
 	GtkTreeSelection *selection = NULL;
 	GtkWidget *vbox=NULL;
-	GtkTreeViewColumn *column1 = NULL;
-	GtkTreeViewColumn *column2 = NULL;
+	
+	GtkWidget *vpaned=NULL;
 
 	GtkTargetEntry dragTargets[] = { { (gchar*)"text/uri-list", 0, DND_URI_TYPE } };
-	GtkTreeStore *treeStore = NULL;
+	GtkTreeStore *projectTreeStore = NULL;
 	GtkAccelGroup* accelgroup = NULL;
 	GError *tempErr = NULL;
+			
+	GtkWidget *recentScrolledWindow=NULL;
 	
+	GtkWidget *recentHbox=NULL;
+
+	GtkWidget *fullVbox=NULL;
+	
+	GtkWidget *hbox=NULL;
+	GtkWidget *statusBarVbox=NULL;
+		
 	clicked_node.valid=FALSE;
 	clicked_node.name=NULL;
 	clicked_node.type=-1;
@@ -208,8 +237,11 @@ gboolean setup_gui(GError **err)
 	gtk_container_set_border_width(GTK_CONTAINER(sMainWindow), 0);	//3
 	g_signal_connect(G_OBJECT(sMainWindow), "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
 	
+	// Main content of the window is a vpaned
 	
-	// Main content of the window is a vbox
+	vpaned=gtk_vpaned_new();
+	
+	// Then we need a vbox
 	
 	if (!(vbox = gtk_vbox_new(FALSE, 0))) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main vbox, gtk_vbox_new() = NULL", __func__);
@@ -217,7 +249,10 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 	
-	gtk_container_add(GTK_CONTAINER(sMainWindow), vbox);
+	//gtk_container_add(GTK_CONTAINER(sMainWindow), vbox);
+	
+	
+	//gtk_container_add(GTK_CONTAINER(sMainWindow), recentVbox);
 	
 	// Create menus
 	
@@ -257,6 +292,8 @@ gboolean setup_gui(GError **err)
 	sGeneralPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/GeneralPopup");
 	sGroupPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/GroupPopup");
 	sFilePopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/FilePopup");
+	
+	recentPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/RecentPopup");
 		
 	// Add a scrolled window to the main window
 	
@@ -269,38 +306,33 @@ gboolean setup_gui(GError **err)
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 	
 	gtk_box_pack_start(GTK_BOX(vbox), scrolledWindow, TRUE, TRUE, 0);
-
-	GtkWidget *hbox;
+	
 	
 	hbox=gtk_hbox_new(FALSE,0);
 	
-	if (!init_statusbar(hbox,&tempErr)) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not init statusbar", tempErr->message);
-		goto EXITPOINT;
-	}
-	
 	gtk_widget_show(hbox);
 	
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,TRUE,0);
-		
+	
+
 	// Create the tree datastore
 	
-	if ((treeStore = create_treestore(&tempErr)) == NULL) {
+	if ((projectTreeStore = create_treestore(&tempErr)) == NULL) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create the treestore", tempErr->message);
 		goto EXITPOINT;
 	}
 		
 	// Create the treeview, set it up to render the tree datastore, and add it to the hbox
 	
-	if (!(sTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(treeStore)))) {
+	if (!(projectTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(projectTreeStore)))) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeView, gtk_tree_view_new_with_model() = NULL", __func__);
 		
 		goto EXITPOINT;
 	}
 	
-	g_object_unref(G_OBJECT(treeStore));
+	g_object_unref(G_OBJECT(projectTreeStore));
 	
-	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(sTreeView),TRUE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(projectTreeView),TRUE);
 	
 	if (!(textCellRenderer = gtk_cell_renderer_text_new())) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_text_new() = NULL", __func__);
@@ -308,6 +340,11 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 	
+	g_object_set(G_OBJECT(textCellRenderer),
+			"editable",FALSE, 
+			"mode",GTK_CELL_RENDERER_MODE_EDITABLE,
+			NULL);
+	
 	if (!(pixbuffCellRenderer = gtk_cell_renderer_pixbuf_new())) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_pixbuf_new() = NULL", __func__);
 		
@@ -320,7 +357,7 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 
-	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(sTreeView), FALSE);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(projectTreeView), FALSE);
 	
 	gtk_tree_view_column_set_resizable(column1, TRUE);
 	gtk_tree_view_column_set_min_width(column1, (int)(gPrefs.width*.75));
@@ -335,61 +372,125 @@ gboolean setup_gui(GError **err)
 	gtk_tree_view_column_add_attribute(column1, textCellRenderer, "weight", COLUMN_FONTWEIGHT);
 	gtk_tree_view_column_add_attribute(column1, textCellRenderer, "weight-set", COLUMN_FONTWEIGHTSET);
 	
-	gtk_tree_view_append_column(GTK_TREE_VIEW(sTreeView), column1);
+	g_signal_connect(G_OBJECT(textCellRenderer), "edited", G_CALLBACK(rename_cb), NULL);
+	
+	gtk_tree_view_append_column(GTK_TREE_VIEW(projectTreeView), column1);
+	
+	// Stoopid gtk always expands the last column
+	
+	gtk_container_add(GTK_CONTAINER(scrolledWindow), projectTreeView);
+		
+	// Get tree events
+	
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(projectTreeView));
+	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
+	
+	g_signal_connect(G_OBJECT(projectTreeView), "row-activated", G_CALLBACK(tree_row_activated_cb), NULL);
+	
+	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(projectTreeView),tree_view_search_equal_func,NULL,NULL);
+	
+	gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(projectTreeView), GDK_BUTTON1_MASK, dragTargets, 1, GDK_ACTION_MOVE);
+	gtk_tree_view_enable_model_drag_dest(GTK_TREE_VIEW(projectTreeView), dragTargets, 1, GDK_ACTION_MOVE);
 	
 	
-	if (!(column2 = gtk_tree_view_column_new_with_attributes("", textCellRenderer, "text", COLUMN_FILESIZE, NULL))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeViewColumn, gtk_tree_view_column_new_with_attributes() = NULL", __func__);
+	sDragStruct.treeView = GTK_TREE_VIEW(projectTreeView);
+	sDragStruct.treeStore = projectTreeStore;
+	sDragStruct.isLocalDrag = FALSE;
+	sDragStruct.dragNodes = NULL;
+	
+	g_signal_connect(G_OBJECT(projectTreeView), "drag-data-received", G_CALLBACK(drag_data_received_cb), &sDragStruct);
+	g_signal_connect(G_OBJECT(projectTreeView), "drag-data-get", G_CALLBACK(drag_data_get_cb), &sDragStruct);
+	g_signal_connect(G_OBJECT(projectTreeView), "drag-motion", G_CALLBACK(drag_motion_cb), &sDragStruct);
+	g_signal_connect(G_OBJECT(projectTreeView), "row-expanded", G_CALLBACK(row_expand_or_collapse_cb), NULL);
+	g_signal_connect(G_OBJECT(projectTreeView), "row-collapsed", G_CALLBACK(row_expand_or_collapse_cb), NULL);
+	
+	g_signal_connect(G_OBJECT(projectTreeView), "button-press-event", G_CALLBACK(mouse_button_pressed_cb), projectTreeView);
+ 	g_signal_connect(G_OBJECT(projectTreeView), "key-press-event", G_CALLBACK(key_press_cb), projectTreeView);
+	
+	// --------------------------------
+	// Recent file stuff:
+	
+	if (!(recentVbox = gtk_vbox_new(FALSE, 0))) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main vbox, gtk_vbox_new() = NULL", __func__);
 		
 		goto EXITPOINT;
 	}
 	
-	// Stoopid gtk always expands the last column
-	
-	gtk_tree_view_append_column(GTK_TREE_VIEW(sTreeView), column2);
-	
-	gtk_container_add(GTK_CONTAINER(scrolledWindow), sTreeView);
+	if (!(recentHbox=gtk_hbox_new(FALSE,0))) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main vbox, gtk_hbox_new() = NULL", __func__);
 		
-	// Get tree events
-	
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
-	
-	g_signal_connect(G_OBJECT(sTreeView), "row-activated", G_CALLBACK(tree_row_activated_cb), NULL);
-	
-	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(sTreeView),tree_view_search_equal_func,NULL,NULL);
-	
-	gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(sTreeView), GDK_BUTTON1_MASK, dragTargets, 1, GDK_ACTION_MOVE);
-	gtk_tree_view_enable_model_drag_dest(GTK_TREE_VIEW(sTreeView), dragTargets, 1, GDK_ACTION_MOVE);
-	
-	
-	sDragStruct.treeView = GTK_TREE_VIEW(sTreeView);
-	sDragStruct.treeStore = treeStore;
-	sDragStruct.isLocalDrag = FALSE;
-	sDragStruct.dragNodes = NULL;
-	
-	g_signal_connect(G_OBJECT(sTreeView), "drag-data-received", G_CALLBACK(drag_data_received_cb), &sDragStruct);
-	g_signal_connect(G_OBJECT(sTreeView), "drag-data-get", G_CALLBACK(drag_data_get_cb), &sDragStruct);
-	g_signal_connect(G_OBJECT(sTreeView), "drag-motion", G_CALLBACK(drag_motion_cb), &sDragStruct);
-	g_signal_connect(G_OBJECT(sTreeView), "row-expanded", G_CALLBACK(row_expand_or_collapse_cb), NULL);
-	g_signal_connect(G_OBJECT(sTreeView), "row-collapsed", G_CALLBACK(row_expand_or_collapse_cb), NULL);
-	
-	g_signal_connect(G_OBJECT(sTreeView), "button-press-event", G_CALLBACK(mouse_button_pressed_cb), sTreeView);
- 	g_signal_connect(G_OBJECT(sTreeView), "key-press-event", G_CALLBACK(key_press_cb), sTreeView);
+		goto EXITPOINT;
+	}
+
+	if ((recentScrolledWindow=init_recent_files(&tempErr)) == NULL) {
 		
+		goto EXITPOINT;
+	}
+	
+	
+	gtk_box_pack_start(GTK_BOX(recentVbox),recentScrolledWindow, TRUE,TRUE,0);
+	gtk_box_pack_end(GTK_BOX(recentVbox),recentHbox,FALSE,TRUE,0);
+	
+	if (!(fullVbox=gtk_vbox_new(FALSE,0))) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create fullVbox, gtk_hbox_new() = NULL", __func__);
 		
+		goto EXITPOINT;
+	}
+
+	statusBarVbox=gtk_vbox_new(FALSE,0);
+	if (!statusBarVbox) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create statusBarVbox, gtk_hbox_new() = NULL", __func__);
+		
+		goto EXITPOINT;
+	}
+
+	gtk_paned_pack1(GTK_PANED(vpaned),vbox,TRUE,FALSE);
+	gtk_paned_pack2(GTK_PANED(vpaned),recentVbox,TRUE,TRUE);
+	
+	gtk_widget_show(vpaned);
+	
+	gtk_box_pack_start(GTK_BOX(fullVbox),vpaned,TRUE,TRUE,0);
+	
+	gtk_widget_show(GTK_WIDGET(fullVbox));
+	
+	if (!init_statusbar(fullVbox,&tempErr)) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not init statusbar", tempErr->message);
+		goto EXITPOINT;
+	}
+	
+		
+	gtk_container_add(GTK_CONTAINER(sMainWindow), fullVbox);
+
+	g_signal_connect(G_OBJECT(recentTreeView), "key-press-event", G_CALLBACK(key_press_cb), recentTreeView);
+
 	gtk_window_resize(GTK_WINDOW(sMainWindow), gPrefs.width, gPrefs.height);
 	gtk_window_move(GTK_WINDOW(sMainWindow),gPrefs.xpos,gPrefs.ypos);
+
+	int window_xsize,window_ysize;
+	gtk_window_get_size(GTK_WINDOW(sMainWindow),&window_xsize,&window_ysize);
+	
+	gtk_paned_set_position(GTK_PANED(vpaned),(int)(window_ysize*0.75));
 	
 	// Show it all....
+			
+	gtk_widget_show(recentHbox);
+		
+	if (!gPrefs.show_recent) {
+		gtk_widget_hide(recentHbox);
+	} else {
+		gtk_widget_show(recentVbox);
+	}
 	
-	gtk_widget_show(sTreeView);
+	gtk_widget_show(projectTreeView);
 	gtk_widget_show(scrolledWindow);
 	gtk_widget_show(vbox);
 	gtk_widget_show(sMainWindow);
 	
 	resultCode = TRUE;
 	
+	// init the filelist
+	init_filelist();
+	
 EXITPOINT:
 	
 	if (tempErr) g_error_free(tempErr);
@@ -407,11 +508,11 @@ void gui_close()
 	
 	if (scrolledWindow) gtk_widget_destroy(scrolledWindow);
 	
-	//unref_tree_graphics();
-	
 	unload_graphics();
 	
 	done_statusbar();
+	
+	done_filelist();
 
 	if (sMainWindow) gtk_widget_destroy(sMainWindow);
 }
@@ -438,7 +539,7 @@ gboolean tree_row_is_expanded(GtkTreePath *path)
 {
 	g_assert(path != NULL);
 	
-	return gtk_tree_view_row_expanded(GTK_TREE_VIEW(sTreeView), path);
+	return gtk_tree_view_row_expanded(GTK_TREE_VIEW(projectTreeView), path);
 }
 
 
@@ -452,7 +553,7 @@ gboolean tree_row_is_expanded(GtkTreePath *path)
 void expand_tree_row(GtkTreePath *path, gboolean expandChildren)
 {
 	if (path!=NULL) {
-		gtk_tree_view_expand_row(GTK_TREE_VIEW(sTreeView), path, FALSE);
+		gtk_tree_view_expand_row(GTK_TREE_VIEW(projectTreeView), path, FALSE);
 	}
 }
 
@@ -465,7 +566,7 @@ void expand_tree_row(GtkTreePath *path, gboolean expandChildren)
  */
 void collapse_tree_row(GtkTreePath *path)
 {
-	gtk_tree_view_collapse_row(GTK_TREE_VIEW(sTreeView), path);
+	gtk_tree_view_collapse_row(GTK_TREE_VIEW(projectTreeView), path);
 }
 
 
@@ -534,6 +635,7 @@ static void switch_folder_icon(GtkTreeView *treeView,GtkTreePath *path)
 	g_free(relFilePath);
 }
 
+
 /**
  * Callback handler for Gtk "row-activated" event.
  *
@@ -573,14 +675,8 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 	}
 	
 	absFilePath=fix_path((gchar*)get_project_directory(),relFilePath);
-	
-	debug_printf("absFilePath:%s\n",absFilePath);
-	debug_printf("relFilePath:%s\n",relFilePath);
 
 	fixed=fix_path((gchar*)get_project_directory(),relFilePath);
-
-	debug_printf("fixed:%s\n",fixed);
-	debug_printf("relFilePath:%s\n",relFilePath);
 	
 	if ((command = g_strdup_printf("open:%s\n", fixed)) == NULL) {
 		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
@@ -595,6 +691,8 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 				send_scite_command((gchar*)"focus:0",NULL);
 			}
 			
+			add_file_to_recent(fixed,NULL);
+			
 			gchar *statusbar_text=NULL;
 			
 			statusbar_text=g_strdup_printf("Opened %s",remove_newline(get_filename_from_full_path(command)));
@@ -638,6 +736,7 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	gchar *nodeName = NULL;
 	gint nodeItemType;
 	GtkTreeIter iter;
+	GtkTreeSelection *tree_selection=NULL;
 	
 	g_assert(treeView != NULL);
 	g_assert(event != NULL);
@@ -688,8 +787,6 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	nodeName = NULL;
 	
 	// Check if something is selected
-	GtkTreeSelection *tree_selection=NULL;
-	
 	tree_selection=gtk_tree_view_get_selection(GTK_TREE_VIEW(treeView));
 	
 	if (tree_selection!=NULL) {
@@ -745,6 +842,7 @@ EXITPOINT:
 	if (err) g_error_free(err);
 }
 
+
 /**
  *
  */
@@ -764,93 +862,6 @@ EXITPOINT:
 	if (err) g_error_free(err);
 }
 
-/**
- * Add files to a group or the root of the tree
- */
-static void popup_add_files_cb()
-{
-	GtkWidget *dialog = NULL;
-	GError *err = NULL;
-	GtkTreeIter *nodeIter = NULL;
-
-	debug_printf("%s!\n",__func__);
-	
-	// Files cannot be added to files!
-	
-	if (clicked_node.valid && clicked_node.type == ITEMTYPE_FILE) {
-		goto EXITPOINT;
-	}
-		
-	// Add to the root or to a group?
-	
-	if (clicked_node.valid) {
-		nodeIter = &(clicked_node.iter);
-	}
-	
-	if (!add_files_to_project(nodeIter, &err)) {
-		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "An error occurred while trying add files to the project: %s", err->message);
-		
-		gtk_dialog_run(GTK_DIALOG(dialog));
-	} else {
-
-	}
-	
-	
-EXITPOINT:
-	
-	if (err) g_error_free(err);
-	if (dialog) gtk_widget_destroy(dialog);
-}
-
-/**
- *
- */
-gboolean open_filename(gchar *filename,GError **err)
-{
-	gchar *command=NULL;
-	
-	if (!relative_path_to_abs_path(filename, &filename, get_project_directory(), err)) {
-		return FALSE;
-	}
-	
-	// It's a file, so try to open it
-	
-	if ((command = g_strdup_printf("open:%s\n", filename)) == NULL) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
-	}
-	else {
-		if (send_scite_command(command, err)) {
-			// Try to activate SciTE; ignore errors
-			
-			activate_scite(NULL);
-			
-			if (gPrefs.give_scite_focus==TRUE) {
-				send_scite_command((gchar*)"focus:0",NULL);
-			}
-		}
-	}
-	
-	return TRUE;
-}
-
-
-/**
- *
- */
-static void _selected_helper (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-	gint nodeItemType;
-	gchar *relFilePath;
-	
-	GError **err=NULL;
-		
-	gtk_tree_model_get(model, iter, COLUMN_ITEMTYPE, &nodeItemType, COLUMN_FILEPATH, &relFilePath, -1);
-	
-	if (nodeItemType==ITEMTYPE_FILE) {
-		
-		open_filename(relFilePath,err);
-	}
-}
 
 
 /**
@@ -865,15 +876,6 @@ static void popup_open_file_cb()
 	gchar *absFilePath = NULL;
 	
 	// several files in selection?
-	
-	GtkTreeSelection *tree_selection=NULL;
-	
-	tree_selection=gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	
-	if (tree_selection!=NULL) {
-		
-		gtk_tree_selection_selected_foreach (tree_selection, _selected_helper, NULL);
-	}
 		
 	// We can only open files
 	
@@ -881,10 +883,12 @@ static void popup_open_file_cb()
 		goto EXITPOINT;
 	}
 	
-	if (!open_filename(clicked_node.name,&err)) {
+	if (!open_filename(clicked_node.name,(gchar*)(get_project_directory()),&err)) {
 		goto EXITPOINT;
 	}
 	
+	add_file_to_recent(clicked_node.name,NULL);
+	
 	
 EXITPOINT:
 	
@@ -900,197 +904,6 @@ EXITPOINT:
 	if (dialog) gtk_widget_destroy(dialog);	
 }
 
-/**
- *		Actually remove selected nodes
- */
-void remove_selected_items ( GtkTreeView *treeview )
-{
-	GtkTreeSelection *selection = gtk_tree_view_get_selection ( treeview );
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-
-	//GtkTreeStore *store;
-	
-	GError *error=NULL;
-   
-	if (gtk_tree_selection_count_selected_rows(selection) == 0)
-		return;
-	
-	model=gtk_tree_view_get_model(treeview);
-
-	GList *list = gtk_tree_selection_get_selected_rows( selection, &model );
-
-	int nRemoved = 0;
-	
-	// Begin at the end and go to the start
-	
-	list=g_list_last(list);
-	while(list) {
-		GString *fixed_path = g_string_new("");
-		g_string_printf(fixed_path, "%s", gtk_tree_path_to_string((GtkTreePath*)list->data)/*ipath*/);
-
-		GtkTreePath *path = gtk_tree_path_new_from_string(fixed_path->str);
-		g_string_free(fixed_path, TRUE);
-
-		if (path) {
-			if ( gtk_tree_model_get_iter ( model, &iter, path) ) { // get iter from specified path
-					
-				remove_tree_node(&iter,&error);
-				nRemoved++;   
-			}
-			else { // invalid path
-				g_error("Error!!!\n");
-			}
-			gtk_tree_path_free (path);
-		}
-		else {
-			g_error("Error!!!\n");
-		}
-		list=list->prev;
-	}
-	
-	g_list_foreach (list, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (list);
-}
-
-
-/**
- *
- */
-static void do_remove_node(gboolean ignore_clicked_node)
-{
-	GError *err = NULL;
-	GtkWidget *dialog = NULL;
-	gint dialogResponse;
-	gchar *nodename = NULL;
-	
-	gint selected_rows=0;
-	
-	gboolean multiple_selected=FALSE;
-	
-	// Make sure a node has been selected
-	if (!ignore_clicked_node) {
-		if (!clicked_node.valid) {
-			goto EXITPOINT;
-		}
-	}
-	
-	GtkTreeSelection *treeSelect;
-	
-	treeSelect=gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	
-	selected_rows=gtk_tree_selection_count_selected_rows(treeSelect);
-	if (selected_rows>1) {
-		multiple_selected=TRUE;
-	}
-	
-	if (!ignore_clicked_node) {
-		// Figure out the node name
-		nodename = strrchr(clicked_node.name, '/');
-		
-		if (nodename != NULL) {
-			++nodename;
-		}
-		else {
-			nodename = clicked_node.name;
-		}
-	} else {
-		// if there is only one selected, get its name
-		nodename=NULL;
-		multiple_selected=TRUE;
-	}
-		
-	// Confirm removal from project
-	
-	if (multiple_selected==TRUE) {
-		
-		dialog=gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, "Remove all selected items?" /*, nodename*/);
-		
-		dialogResponse = gtk_dialog_run(GTK_DIALOG (dialog));
-		
-		if (dialog_response_is_exit(dialogResponse)) {
-			goto EXITPOINT;
-		}
-		
-		// remove them!
-		remove_selected_items(GTK_TREE_VIEW(sTreeView));
-
-	} else {
-		
-		if (clicked_node.type == ITEMTYPE_FILE) {
-			if (nodename!=NULL) {
-				dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, "Remove file '%s' from project?", nodename);
-			} else {
-				dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, "Remove file from project?");
-			}
-		}
-		else {
-			if (nodename!=NULL) {
-				dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, "Remove group '%s' and any contained files from project?", nodename);
-			} else {
-				dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, "Remove group and any contained files from project?");
-			}
-		}
-		
-		dialogResponse = gtk_dialog_run(GTK_DIALOG (dialog));
-		if (dialog_response_is_exit(dialogResponse)) {
-			goto EXITPOINT;
-		}
-		
-		
-		// Remove the node
-		
-		if (!remove_tree_node(&(clicked_node.iter), &err)) {
-			GtkWidget *errDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Could not remove the selected node: \n\n%s", err->message);
-			
-			gtk_dialog_run(GTK_DIALOG (errDialog));
-			
-			gtk_widget_destroy(errDialog);	
-		}
-	}
-	
-EXITPOINT:
-	
-	if (err) g_error_free(err);
-	if (dialog) gtk_widget_destroy(dialog);	
-}
-
-
-/**
- * Remove the selected file/group.
- */
-static void popup_remove_node_cb()
-{
-	do_remove_node(FALSE);
-}
-
-
-
-/**
- * Add a group to the root of the tree, or to an existing group
- */
-static void popup_add_group_cb()
-{
-	GtkTreeIter *nodeIter = NULL;
-	
-	// Groups cannot be added to files!
-	if (clicked_node.valid && clicked_node.type == ITEMTYPE_FILE) {
-		goto EXITPOINT;
-	}
-		
-	// Are we adding this to the root of the tree, or to an existing group?
-	if (clicked_node.valid) {
-		nodeIter = &(clicked_node.iter);
-	}
-	
-	ask_name_add_group(nodeIter);
-	
-	
-EXITPOINT:
-	
-	return;
-}
-
 
 
 
@@ -1114,7 +927,6 @@ void set_window_title(const gchar *newName)
 	
 	window_saved_title=g_strdup_printf("%s",newName);
 	
-	
 	g_free(temp_string);
 }
 
@@ -1144,89 +956,12 @@ void update_project_is_dirty(gboolean dirty)
 
  
 /**
- * Ask the user for the name of a group and add it to the tree
- *
- * @param nodeIter is the node the group will be added to as a child; if NULL, then the group is added to the root of the tree
+ * step-through function for expand/collapse folder
+ *	
+ * @param tree_view
+ * @param newiter
+ * @param tree_path
  */
-static void ask_name_add_group(GtkTreeIter *nodeIter)
-{
-	GError *err = NULL;
-	GtkWidget *dialog = NULL;
-	GtkWidget* gtkEntry = NULL;
-	GtkWidget* gtkLabel = NULL;
-	GtkWidget* table = NULL;
-	GtkAttachOptions options = (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL);
-	const gchar *groupName = NULL;
-	gint dialogResponse;
-	
-	
-	// Create a dialog box with a nicely-centered text entry widget
-	dialog = gtk_dialog_new_with_buttons("Choose Group Name", NULL, GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
-	
-	g_signal_connect(dialog, "response",  G_CALLBACK(gtk_widget_hide), dialog);
-	
-	gtk_container_set_border_width(GTK_CONTAINER(dialog), 0);
-	
-	table = gtk_table_new(1, 2, FALSE);
-	
-	gtkLabel = gtk_label_new("Enter name of new group:");
-	gtk_table_attach(GTK_TABLE(table), gtkLabel, 0, 1, 0, 1, options, options, 5, 5);
-	
-	gtkEntry = gtk_entry_new();
-	g_signal_connect(GTK_OBJECT(gtkEntry), "activate", G_CALLBACK(entry_widget_activated_cb), dialog);
-	gtk_table_attach(GTK_TABLE(table), gtkEntry, 1, 2, 0, 1, options, options, 5, 5);
-	
-	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
-	
-	gtk_widget_show_all(dialog);
-	
-	
-	// Let the user enter a name or cancel the whole thing
-	
-	dialogResponse=gtk_dialog_run(GTK_DIALOG(dialog));
-	if (dialog_response_is_exit(dialogResponse)) {
-		goto EXITPOINT;
-	}
-	
-	groupName = gtk_entry_get_text(GTK_ENTRY(gtkEntry));
-	
-	if (groupName == NULL || *groupName == '\0') {
-		GtkWidget *errDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Invalid group name");
-		
-		gtk_dialog_run(GTK_DIALOG(errDialog));
-		
-		gtk_widget_destroy(errDialog);
-		
-		goto EXITPOINT;
-	}
-	
-	
-	// Add the group
-	
-	if (!add_tree_group(nodeIter, ADD_CHILD, groupName, TRUE, NULL, &err)) {
-		GtkWidget *errDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "An error occurred while adding the group: %s", err->message);
-		
-		gtk_dialog_run(GTK_DIALOG(errDialog));
-		
-		gtk_widget_destroy(errDialog);
-	}
-	
-	
-EXITPOINT:
-	
-	// Destroying the dialog should also destroy the table, label, and entry widgets
-	if (gtkLabel) gtk_widget_destroy(GTK_WIDGET(gtkLabel));
-	if (table) gtk_widget_destroy(GTK_WIDGET(table));
-
-	if (dialog) gtk_widget_destroy(GTK_WIDGET(dialog));
-	
-	if (err) g_error_free(err);
-	
-	// Do NOT free groupName, since that is owned by the GtkEntry widget!
-}
-
-
-
 static void fix_folders_step_through(GtkTreeView *tree_view, GtkTreeIter newiter,GtkTreePath *tree_path)
 {
 	GtkTreeModel *tree_model = gtk_tree_view_get_model(tree_view);
@@ -1316,15 +1051,6 @@ static void about_menu_cb()
 }
 
 
-/**
- * Callback for "Usage" menu item
- */
-static void usage_menu_cb()
-{
-	show_usage_dialog();
-}
-
-
 /**
  * Callback for "Save Project As..." menu item
  */
@@ -1345,6 +1071,7 @@ static void saveproject_as_menu_cb()
 	if (err) g_error_free(err);
 }
 
+
 /**
  * Callback for "Save Project" menu item
  */
@@ -1400,110 +1127,6 @@ static void creategroup_menu_cb()
 }
 
 
-/**
- * Callback for Remove Item(s) menu item
- */
-static void removeitem_menu_cb()
-{
-	do_remove_node(TRUE);
-}
-
-
-
-/**
- * Callback for "Add File" menu item
- */
-static void addfile_menu_cb()
-{
-	GError *err = NULL;
-	
-	// Get the selction, and add to that group
-	
-	GtkTreeIter *parentIter=NULL;
-	
-	GtkTreeIter nodeIter;
-	
-	gboolean nodeValid=FALSE;
-	
-	GList *list=NULL;
-	
-	GtkTreeSelection *treeSelection = gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	
-	GtkTreeModel *tree_model=gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)); //GTK_TREE_MODEL(get_treestore(&err));
-	
-	list = gtk_tree_selection_get_selected_rows(treeSelection, NULL);
-	
-	// is the list empty?
-	if (list) {
-		list=g_list_first(list);
-		
-		GtkTreePath *path=(GtkTreePath*)list->data;
-
-		gtk_tree_model_get_iter (tree_model, &nodeIter, path);
-	
-		nodeValid=TRUE;
-			
-		g_list_foreach (list, (GFunc)(gtk_tree_path_free), NULL);
-		g_list_free (list);
-
-	}
-	
-	if (nodeValid) {
-		
-		int nodeType=-1;
-		gtk_tree_model_get(tree_model, &nodeIter, COLUMN_ITEMTYPE, &nodeType, -1);
-		
-		if (nodeType==ITEMTYPE_GROUP) {
-			parentIter=&nodeIter;
-		} else {
-			GtkTreeIter newIter;
-			if (gtk_tree_model_iter_parent(tree_model,&newIter,&nodeIter)) {
-				parentIter=&newIter;
-			}				
-			
-		}
-	}
-	
-	
-	if (parentIter!=NULL) {
-		gchar *nodeContents=NULL;
-		gtk_tree_model_get(tree_model, parentIter, COLUMN_FILENAME, &nodeContents, -1);
-		
-		g_free(nodeContents);
-	} else {
-
-	}
-	
-	if (!add_files_to_project(parentIter, &err)) {
-		GtkWidget *dialog = gtk_message_dialog_new(NULL, 
-					GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-					"An error occurred while trying add files to the project: %s", err->message);
-		
-		if (dialog) {
-			gtk_dialog_run(GTK_DIALOG(dialog));
-			
-			gtk_widget_destroy(dialog);
-		}
-	} 
-	
-	if (err) g_error_free(err);
-}
-
-
-
-/**
- * Callback for menu manager to populate GUI widgets
- *
- * @param ui is the GtkUIManager
- * @param widget is the GtkWidget to add to the UI
- * @param container is the container to add widget to
- */
-static void menu_add_widget_cb(GtkUIManager *ui, GtkWidget *widget, GtkContainer *container)
-{
-	gtk_box_pack_start(GTK_BOX(container), widget, FALSE, FALSE, 0);
-	gtk_widget_show(widget);
-}
-
 /**
  *
  */
@@ -1528,7 +1151,13 @@ gboolean key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer userData)
 		}
 		case GDK_F2:
 		{
-			rename_key_pressed_cb();
+			do_rename_node(TRUE);
+			return TRUE;
+			break;
+		}
+		case GDK_F5:
+		{
+			print_filelist();
 			break;
 		}
 		default: 
@@ -1563,6 +1192,7 @@ static gboolean foreach_expand(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter
 	return FALSE;
 }
 
+
 /**
  *		Collapses all folders
  */
@@ -1572,12 +1202,13 @@ static gboolean foreach_collapse(GtkTreeModel *model,GtkTreePath *path,GtkTreeIt
 	return FALSE;
 }
 
+
 /**
  *
  */
 static void expand_all_items_cb()
 {
-	gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),foreach_expand,NULL);
+	gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(projectTreeView)),foreach_expand,NULL);
 }
 
 
@@ -1586,7 +1217,7 @@ static void expand_all_items_cb()
  */
 static void collapse_all_items_cb()
 {
-	gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),foreach_collapse,NULL);
+	gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(projectTreeView)),foreach_collapse,NULL);
 }
 
 
@@ -1606,8 +1237,6 @@ void edit_options_cb()
 	
 	absFilePath=g_strdup_printf("%s/.sciteproj",homedir);
 	
-	debug_printf("absFilePath:%s\n",absFilePath);
-	
 	if ((command = g_strdup_printf("open:%s\n", absFilePath)) == NULL) {
 		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
 	}
@@ -1622,19 +1251,11 @@ void edit_options_cb()
 			}
 		}
 	}	
+	
+	g_free(absFilePath);
 }
 
 
-
-
-/**
- *
- */
-GtkWidget *get_main_window()
-{
-	return sMainWindow;
-}
-
 /**
  *		search function for the gtk_tree_view_set_search_equal_func
  *		@return TRUE when rows DONT match, FALSE when rows match
@@ -1655,3 +1276,38 @@ gboolean tree_view_search_equal_func(GtkTreeModel *model,gint column,const gchar
 	
 	return res;
 }
+
+
+
+/**
+ *
+ */
+gboolean dialog_response_is_exit(gint test)
+{
+	gboolean result=FALSE;
+	
+	if ((test==GTK_RESPONSE_REJECT) || (test==GTK_RESPONSE_CANCEL) || 
+		 (test==GTK_RESPONSE_DELETE_EVENT) || (test==GTK_RESPONSE_NONE)) {
+		result=TRUE;
+	}
+	
+	return result;
+}
+
+
+/**
+ *
+ */
+void recent_files_switch_visible()
+{
+	gboolean visible=FALSE;
+	
+	g_object_get(G_OBJECT(recentVbox),"visible", &visible,NULL);
+	
+	if (visible) {
+		gtk_widget_hide(recentVbox);
+		gtk_widget_grab_focus(projectTreeView);
+	} else {
+		gtk_widget_show(recentVbox);
+	}
+}
