@@ -1,6 +1,7 @@
-/* gui.h - GUI code for SciteProj
+/**
+ * gui.h - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -21,26 +22,17 @@
 #ifndef __HEADER_GUI_
 #define __HEADER_GUI_
 	
-/**
- *
- */
-struct ClickedNode
-{
-	gboolean valid;
-	GtkTreeIter iter;
-	gchar *name;
-	gint type;
-};
-
-typedef struct ClickedNode ClickedNode;
-
 /**
  * Variables
  */
 extern gchar *window_saved_title;
-extern GtkWidget *sTreeView;
+extern GtkWidget *projectTreeView;
+extern GtkWidget *recentTreeView;
+extern GtkCellRenderer *textCellRenderer;
 extern ClickedNode clicked_node;
 
+extern GtkTreeViewColumn *column1;
+
 
 // Initialize the GUI
 gboolean setup_gui(GError **err);
@@ -64,7 +56,7 @@ void get_dimensions(gint *left, gint *top, gint *width, gint *height);
 
 void update_project_is_dirty(gboolean dirty);
 
-GtkWidget *get_main_window();
+gboolean dialog_response_is_exit(gint test);
 
 
 #endif /*__HEADER_GUI_*/
