@@ -1,6 +1,7 @@
-/* main.c - main for SciteProj
+/**
+ * main.c - main for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -25,6 +26,7 @@
 #include <glib.h>
 #include <string.h>
 
+#include "clicked_node.h"
 #include "gui.h"
 #include "tree_manipulation.h"
 #include "prefs.h"
@@ -43,6 +45,7 @@ static struct CommandLineIndata {
 
 static void parse_cmd_options(int argc,char *argv[]);
 
+
 /*
  *		Program main entry
  */
@@ -50,6 +53,7 @@ int main(int argc, char *argv[])
 {
 	int returnCode = EXIT_FAILURE;
 	GError *err = NULL;
+	gchar *file_to_load=NULL;
 	
 	parse_cmd_options(argc,argv);
 	
@@ -133,7 +137,7 @@ int main(int argc, char *argv[])
 	}
 	
 	
-	gchar *file_to_load=NULL;
+	file_to_load=NULL;
 	if (cmd.file_to_load!=NULL) {
 		file_to_load=cmd.file_to_load;
 	} else {
@@ -148,10 +152,8 @@ int main(int argc, char *argv[])
 			gtk_dialog_run(GTK_DIALOG(errDialog));
 			gtk_widget_destroy(errDialog);
 			
-			if (err) {
-				g_error_free(err);
-				err = NULL;
-			}
+			g_error_free(err);
+			err = NULL;
 		}
 	}
 	
