@@ -1,6 +1,7 @@
-/* prefs.c - prefs for SciteProj
+/**
+ * prefs.c - prefs for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -39,14 +40,29 @@ gchar *default_config_string=(gchar*)"" \
 				"width=200\n"
 				"height=400\n"
 				"\n"
+				"# Search window geometry (-1 on xpos and ypos means default center screen):\n"
+				"search_xpos=-1\n"
+				"search_ypos=-1\n"
+				"search_width=500\n"
+				"search_height=400\n"
+				"\n"
+				"search_alert_file_warnings=TRUE\n"
+				"search_match_case=FALSE\n"
+				"search_match_whole_words=FALSE\n"
+				"search_trim_results=TRUE\n"
+				"\n"
 				"#other:\n"
 				"give_scite_focus=FALSE\n"
+				"search_give_scite_focus=TRUE\n"
 				"dirty_on_folder_change=FALSE\n"
 				"\n"
 				"allow_duplicates=TRUE\n"
 				"\n"
 				"identify_sciteproj_xml=TRUE\n"
 				"\n"
+				"show_recent=FALSE\n"
+				"recent_add_to_bottom=FALSE\n"
+				"\n"
 				"\n";
 
 
@@ -82,13 +98,10 @@ gboolean check_config_string(gchar *in_config)
 		value++;
 	}
 	
-	//gchar *new_tempstring,*new_value;
-	
 	if ((tempstring!=NULL) && (value!=NULL)) {
 	
 		tempstring=g_strchug(tempstring);
 		tempstring=g_strchomp(tempstring);
-		//new_tempstring=g_ascii_strup(tempstring,-1);
 
 		value=g_strchug(value);
 		value=g_strchomp(value);
@@ -113,48 +126,100 @@ gboolean check_config_string(gchar *in_config)
 			gPrefs.height=(int)tempdouble;
 		}
 		
-		gPrefs.give_scite_focus=FALSE;
-		if (g_ascii_strcasecmp(tempstring,"give_scite_focus")==0) {
-			
-			if (g_ascii_strcasecmp(value,"TRUE")==0) {
-				//printf("give_scite_focus=TRUE");
-				gPrefs.give_scite_focus=TRUE;
-				
-			}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_xpos")==0) {
+			tempdouble=g_ascii_strtod(value,NULL);
+			gPrefs.search_xpos=(int) tempdouble;
 		}
-		gPrefs.dirty_on_folder_change=FALSE;
-		if (g_ascii_strcasecmp(tempstring,"dirty_on_folder_change")==0) {
-			
+		
+		if (g_ascii_strcasecmp(tempstring,"search_ypos")==0) {
+			tempdouble=g_ascii_strtod(value,NULL);
+			gPrefs.search_ypos=(int)tempdouble;
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_width")==0) {
+			tempdouble=g_ascii_strtod(value,NULL);
+			gPrefs.search_width=(int)tempdouble;
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_height")==0) {
+			tempdouble=g_ascii_strtod(value,NULL);
+			gPrefs.search_height=(int)tempdouble;
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"give_scite_focus")==0) {
 			if (g_ascii_strcasecmp(value,"TRUE")==0) {
-				//printf("give_scite_focus=TRUE");
+				gPrefs.give_scite_focus=TRUE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_give_scite_focus")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.search_give_scite_focus=TRUE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_alert_file_warnings")==0) {
+			if (g_ascii_strcasecmp(value,"FALSE")==0) {
+				gPrefs.search_alert_file_warnings=FALSE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_match_case")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.search_match_case=TRUE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_match_whole_words")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.search_match_whole_words=TRUE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"dirty_on_folder_change")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
 				gPrefs.dirty_on_folder_change=TRUE;
-				
 			}
 		}
 		
-		gPrefs.allow_duplicates=TRUE;
 		if (g_ascii_strcasecmp(tempstring,"allow_duplicates")==0) {
 			if (g_ascii_strcasecmp(value,"FALSE")==0) {
 				gPrefs.allow_duplicates=FALSE;
 			}
 		}
 		
-		gPrefs.scite_path=NULL;
 		if (g_ascii_strcasecmp(tempstring,"scite_path")==0) {
 			gPrefs.scite_path=g_strdup_printf("%s",value);
 		}
 		
-		gPrefs.file_to_load=NULL;
 		if (g_ascii_strcasecmp(tempstring,"file_to_load")==0) {
 			gPrefs.file_to_load=g_strdup_printf("%s",value);
 		}
 		
-		gPrefs.identify_sciteproj_xml=FALSE;
 		if (g_ascii_strcasecmp(tempstring,"identify_sciteproj_xml")==0) {
 			if (g_ascii_strcasecmp(value,"TRUE")==0) {
 				gPrefs.identify_sciteproj_xml=TRUE;
 			}
 		}
+		
+		if (g_ascii_strcasecmp(tempstring,"show_recent")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.show_recent=TRUE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"recent_add_to_bottom")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.recent_add_to_bottom=TRUE;
+			}
+		}
+		
+		if (g_ascii_strcasecmp(tempstring,"search_trim_results")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.search_trim_results=TRUE;
+			}
+		}
 	}
 	
 	if (tempstring!=NULL) g_free(tempstring);
@@ -175,6 +240,12 @@ gboolean init_prefs(GError **err)
 	gchar *config_string=NULL;
 	
 	gboolean result=TRUE;
+
+	// the list of strings
+	gchar **list=NULL;
+	gchar **savedlist=NULL;
+
+	gchar *temp=NULL;
 	
 	// Set default values
 	gPrefs.lhs=1;
@@ -183,13 +254,34 @@ gboolean init_prefs(GError **err)
 	gPrefs.verbosity=0; // No informational messages
 	gPrefs.last_file_filter=-1; // All files (my choice)
 	
+	gPrefs.search_xpos=-1;
+	gPrefs.search_ypos=-1;
+	
+	gPrefs.search_width=500;
+	gPrefs.search_height=400;
+	
 	gPrefs.give_scite_focus=FALSE;
+	gPrefs.search_give_scite_focus=TRUE;
 	gPrefs.dirty_on_folder_change=FALSE;
 	
+	gPrefs.search_alert_file_warnings=TRUE;
+	
+	gPrefs.search_match_case=FALSE;
+	gPrefs.search_match_whole_words=FALSE;
+	
 	gPrefs.allow_duplicates=TRUE;
 	
+	gPrefs.show_recent=FALSE;
+	gPrefs.recent_add_to_bottom=FALSE;
+	
 	gchar *config_filename=NULL;
 	
+	gPrefs.file_to_load=NULL;
+	
+	gPrefs.scite_path=NULL;
+	
+	gPrefs.search_trim_results=FALSE;
+	
 	config_filename=g_build_filename(g_get_home_dir(),".sciteproj",NULL);
 	
 	// Check if a config-file exists
@@ -207,15 +299,10 @@ gboolean init_prefs(GError **err)
 		goto ERROR;
 	}
 	
-	// the list of strings
-	gchar **list=NULL;
-	
 	// split out the lines, and add each to the list of strings
 	list=g_strsplit(config_string,"\n",-1);
 	
-	gchar **savedlist=list;
-	
-	gchar *temp=NULL;
+	savedlist=list;
 	
 	do {
 		temp=*list;
