@@ -1,6 +1,7 @@
-/* prefs.h - prefs for SciteProj
+/**
+ * prefs.h - prefs for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -33,8 +34,15 @@ typedef struct {
 	int last_file_filter;
 	int xpos,ypos;
 	
+	int search_xpos,search_ypos;
+	int search_width,search_height;
+	
 	gboolean dirty_on_folder_change;
 	gboolean give_scite_focus;
+	gboolean search_give_scite_focus;
+	
+	gboolean search_match_whole_words;
+	gboolean search_match_case;
 	
 	gboolean allow_duplicates;
 	
@@ -44,6 +52,12 @@ typedef struct {
 	
 	gboolean identify_sciteproj_xml;
 	
+	gboolean show_recent;
+	gboolean recent_add_to_bottom;
+	
+	gboolean search_alert_file_warnings;
+	gboolean search_trim_results;
+	
 } sciteproj_prefs;
 
 extern sciteproj_prefs gPrefs;
