@@ -1,6 +1,7 @@
-/* properties_dialog.c - Properties Dialogs code for SciteProj
+/**
+ * properties_dialog.c - Properties Dialogs code for SciteProj
  *
- *  Copyright 2009-2011 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -26,10 +27,12 @@
 
 #include "properties_dialog.h"
 #include "tree_manipulation.h"
+#include "clicked_node.h"
 #include "gui.h"
 
 #include "string_utils.h"
 
+
 /**
  * 
  */
@@ -91,7 +94,6 @@ void group_properties_gui(GtkTreeModel *tree_model,GtkTreeIter *iter)
 {
 	GError *err = NULL;
 	GtkWidget *dialog = NULL;
-	gint dialogResponse;
 	gchar *nodename = NULL;
 	
 	GtkWidget *table;
@@ -154,12 +156,14 @@ void group_properties_gui(GtkTreeModel *tree_model,GtkTreeIter *iter)
 	
 	gtk_container_set_border_width(GTK_CONTAINER(table),5);
 	
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),table,TRUE,TRUE,0);
+	GtkWidget *container_vbox=gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+	gtk_box_pack_start(GTK_BOX(container_vbox),table,TRUE,TRUE,0);
+
 	
 	gtk_widget_show_all(dialog);
 	
 	
-	dialogResponse=gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_dialog_run(GTK_DIALOG(dialog));
 	
 	
 //EXITPOINT:
@@ -178,13 +182,13 @@ void file_properties_gui(GtkTreeModel *model,GtkTreeIter *iter)
 	
 	GError *err = NULL;
 	GtkWidget *dialog = NULL;
-	gint dialogResponse;
 	gchar *nodename = NULL;
 	
 	GtkWidget *table;
 	GtkWidget *label1,*label2,*label3;
 	GtkWidget *path,*filename,*filesize_label;
-	
+	GtkWidget *container_vbox=NULL;
+
 	gchar *filePath=NULL;
 	int nodeType=-1;
 	
@@ -249,12 +253,14 @@ void file_properties_gui(GtkTreeModel *model,GtkTreeIter *iter)
 	
 	gtk_container_set_border_width(GTK_CONTAINER(table),5);
 	
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),table,TRUE,TRUE,0);
+	
+	container_vbox=gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+	gtk_box_pack_start(GTK_BOX(container_vbox),table,TRUE,TRUE,0);
 	
 	gtk_widget_show_all(dialog);
 	
 	
-	dialogResponse=gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_dialog_run(GTK_DIALOG(dialog));
 	
 	
 EXITPOINT:
@@ -269,22 +275,10 @@ EXITPOINT:
  */
 void group_properties_cb()
 {
-	gint selected_rows=0;
-	gboolean multiple_selected=FALSE;
-	
-	GtkTreeSelection *treeSelect;
-	
-	treeSelect=gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	
-	selected_rows=gtk_tree_selection_count_selected_rows(treeSelect);
-	if (selected_rows>1) {
-		multiple_selected=TRUE;
-	}
-		
 	if (!clicked_node.valid || clicked_node.type != ITEMTYPE_GROUP) {
 		//goto EXITPOINT;
 	} else {
-		group_properties_gui(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),&(clicked_node.iter));
+		group_properties_gui(gtk_tree_view_get_model(GTK_TREE_VIEW(projectTreeView)),&(clicked_node.iter));
 		
 	}
 }
@@ -295,22 +289,10 @@ void group_properties_cb()
  */
 void file_properties_cb()
 {
-	gint selected_rows=0;
-	gboolean multiple_selected=FALSE;
-	
-	GtkTreeSelection *treeSelect;
-	
-	treeSelect=gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	
-	selected_rows=gtk_tree_selection_count_selected_rows(treeSelect);
-	if (selected_rows>1) {
-		multiple_selected=TRUE;
-	}
-		
 	if (!clicked_node.valid || clicked_node.type != ITEMTYPE_FILE) {
 		//goto EXITPOINT;
 	} else {
-		file_properties_gui(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),&(clicked_node.iter));
+		file_properties_gui(gtk_tree_view_get_model(GTK_TREE_VIEW(projectTreeView)),&(clicked_node.iter));
 		
 	}
 }
