@@ -1,6 +1,7 @@
-/* rename.c - rename code for SciteProj
+/**
+ * rename.h - code for renaming a group for SciteProj
  *
- *  Copyright 2009-2011 Andreas Ronnquist
+ *  Copyright 2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -24,12 +25,9 @@
 /**
  *
  */
-void rename_key_pressed_cb();
-
 void popup_rename_group_cb();
-
-gchar *rename_dialog(gchar *source_name,gboolean *cancel_result);
-void entry_widget_activated_cb(GtkEntry *entry, gpointer dialog);
-
+void do_rename_node(gboolean ignore_clicked_node);
+void do_rename_iter(GtkTreeIter iter);
+void rename_cb(gchar *new_text, gchar *path_string,gpointer user_data);
 
 #endif /*__HEADER_RENAME_*/
