@@ -1,6 +1,7 @@
-/* statusbar.c - statusbar for SciteProj
+/**
+ * statusbar.c - statusbar for SciteProj
  *
- *  Copyright 2009-2011 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -54,7 +55,7 @@ gboolean init_statusbar(GtkWidget *widget,GError **err)
 	
 	gtk_widget_set_size_request(statusbar, -1, 20);
 	
-	gtk_box_pack_start (GTK_BOX (widget), statusbar,TRUE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (widget), statusbar,FALSE, FALSE, 0);
 	gtk_widget_show (statusbar);
 
 	
