@@ -1,6 +1,7 @@
-/* tree_manipulation.h - GtkTreeView manipulation code for SciteProj
+/**
+ * tree_manipulation.h - GtkTreeView manipulation code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -15,7 +16,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #ifndef __HEADER_TREE_MANIPULATION_
@@ -55,6 +57,20 @@ enum {
 
 
 
+
+// The types for each column in the tree datamodel
+
+#define TYPE_ITEMTYPE			G_TYPE_UINT
+#define TYPE_FILEPATH			G_TYPE_STRING
+#define TYPE_FILENAME			G_TYPE_STRING
+#define TYPE_FILESIZE			G_TYPE_STRING
+#define TYPE_FONTWEIGHT			G_TYPE_INT
+#define TYPE_FONTWEIGHTSET		G_TYPE_BOOLEAN
+#define TYPE_ICON					GDK_TYPE_PIXBUF
+#define TYPE_EXPANDED			G_TYPE_BOOLEAN
+	
+
+
 typedef gint(*StringCompareFunction)(gconstpointer,gconstpointer);
 
 
