@@ -1,6 +1,7 @@
-/* xml_processing.c - XML processing support for SciteProj
+/**
+ * xml_processing.c - XML processing support for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2008-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2008-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -28,6 +29,7 @@
 #include "xml_processing.h"
 #include "string_utils.h"
 #include "tree_manipulation.h"
+#include "clicked_node.h"
 #include "gui.h"
 #include "file_utils.h"
 
